@@ -2,7 +2,7 @@ use PDF::Font::Loader::FreeType;
 class PDF::Font::Loader::Type1 is PDF::Font::Loader::FreeType {
 
     use PDF::Font::Loader::Type1::Stream;
-    use PDF::DAO;
+    use PDF::COS;
     use PDF::IO::Blob;
 
     method font-file {
@@ -11,7 +11,7 @@ class PDF::Font::Loader::Type1 is PDF::Font::Loader::FreeType {
         my $Length1 = $stream.length[0];
         my $Length2 = $stream.length[1];
         my $Length3 = $stream.length[2];
-        my $font-file = PDF::DAO.coerce: :stream{
+        my $font-file = PDF::COS.coerce: :stream{
             :$decoded,
             :dict{
                 :$Length1, :$Length2, :$Length3,
